WebserviceHelper<T> class

Constructors

WebserviceHelper({required EndpointType endPointType, T? itemFromJson(Map<String, dynamic>)?, Map<String, dynamic>? params, Map<String, dynamic>? queryParameters, FormData? formData, List<String>? path, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress, CancelToken? cancelToken})

Properties

cancelToken → CancelToken?
final
endPointType EndpointType
final
formData → FormData?
final
hashCode int
The hash code for this object.
no setterinherited
itemFromJson → T? Function(Map<String, dynamic>)?
final
onReceiveProgress → ProgressCallback?
final
onSendProgress → ProgressCallback?
final
params Map<String, dynamic>?
final
path List<String>?
getter/setter pair
queryParameters Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post() Future<NetworkResponseObject<T>>
postNormal() Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited