user constant
String
const user
Stores whether user data is available in local storage.
Implementation
static const user = 'user';
Stores whether user data is available in local storage.
static const user = 'user';