AppTheme class

Centralized theme configuration for light and dark modes.

Constructors

AppTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dark ThemeData
Dark theme configuration.
no setter
light ThemeData
Light color scheme and typography used by default.
no setter