Logger class

Constructors

Logger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

a(Object message) → void
curl(Object message) → void
e(Object message) → void
i(Object message) → void
location(Object message) → void
logDef(LogType logType, Object message) → void
logMessage({String title = '', required dynamic message}) → void
s(Object message) → void
size(Object message) → void
w(Object message) → void