PrimaryButton class

Primary filled action button used for high-emphasis actions.

Inheritance

Constructors

PrimaryButton(String title, {double width = 200, double height = 44, VoidCallback? onPressed, Color? backgroundColor, bool isFontBold = false, bool isLoading = false, Color? textColor, IconData? preFixIcon, String? preFixImage, Color? disabledColor, double? alpha, Key? key})
Creates a fixed-size primary button.
const
PrimaryButton.infinity(String title, {double height = 44, VoidCallback? onPressed, Color? backgroundColor, bool isFontBold = false, bool isLoading = false, Key? key, Color? textColor, IconData? preFixIcon, String? preFixImage, Color? disabledColor, double? alpha})
Creates a full-width primary button.
const

Properties

alpha double?
Opacity used for the disabled state.
final
backgroundColor Color?
Optional override for filled background color.
final
disabledColor Color?
Optional override for filled background color.
final
hashCode int
The hash code for this object.
no setterinherited
height double
Target height of the button.
final
isFontBold bool
Whether to force bold title text.
final
isLoading bool
Whether to show a loading spinner and disable tap actions.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed VoidCallback?
Callback invoked when the button is tapped.
final
preFixIcon IconData?
Optional leading icon.
final
preFixImage String?
Optional leading image path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color?
Optional override for filled background color.
final
title String
Visible button label.
final
width double
Target width of the button.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited