TertiaryButtonIconStyle class
Icon style metadata used by TertiaryButton.
Constructors
- TertiaryButtonIconStyle({IconData iconData = Icons.chevron_left, bool iconOnLeft = true})
-
Creates icon style options for a tertiary button.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconData → IconData
-
Icon glyph rendered beside the title.
final
- iconOnLeft → bool
-
Whether the icon should be rendered before the title text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited