Endpoint enum
Built-in endpoint catalog used by WebserviceHelper.
- Inheritance
- Implemented types
- Available extensions
Values
Properties
- baseURL → String
-
Base host URL.
no setteroverride
- contentType → String
-
Request body content type.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, dynamic> -
Request headers to send.
no setteroverride
- httpMethod → EndpointHTTPType
-
HTTP method to use for this endpoint.
no setteroverride
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - path → String
-
Relative endpoint path.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
Full endpoint URL (
baseURL + path).no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited