NetworkResponseObject<T> class
Constructors
-
NetworkResponseObject({required T? itemFromJson(Map<
String, dynamic> )?}) - NetworkResponseObject.fromDetail(bool? status, String message)
Properties
- errorCode ↔ String?
-
getter/setter pair
- errors ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemFromJson
↔ T? Function(Map<
String, dynamic> )? -
getter/setter pair
-
list
↔ List<
T> -
getter/setter pair
- message ↔ String
-
getter/setter pair
- result ↔ T?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ bool?
-
getter/setter pair
Methods
-
fromJson(
Map< String, dynamic> json) → NetworkResponseObject<T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited