Validators class
Validators for common form fields.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
callFunction(
ValidatorType type, String? value) → String? -
Calls the appropriate validator based on
type. -
validateEmail(
String? value) → String? - Validates an email address. Returns null if valid, otherwise an error message.
-
validateMobile(
String? value) → String? - Validates a 10-digit mobile number. Returns null if valid, otherwise an error message.
-
validateName(
String? value) → String? - Validates a name. Returns null if valid, otherwise an error message.
-
validatePassword(
String? value) → String? - Validates a password. Returns null if valid, otherwise an error message.